/*
 * Created on Oct 27, 2004
 * Copyright (C) Andrea Schweer, 2004
 *
 * This file is part of the Greenstone Alerting Service.
 * Refer to the COPYING file in the base directory of this package
 * for licensing information.
 */
package org.greenstone.gsdlas.profiles;

import java.util.*;
import java.util.Map;
import java.util.TreeMap;

/**
 * @author schweer
 * 
 * TODO To change the template for this generated type comment go to Window -
 * Preferences - Java - Code Style - Code Templates
 */
public class Subscription implements Comparable {
    private Map map;
    private int id;
    private int numOfNonEqualsPredicates;
    
    private static int highestId = 0;

    public Subscription(Map valueMap) throws ParseException {
        map = new TreeMap();
        for (Iterator iter = valueMap.keySet().iterator(); iter.hasNext();) {
            String key = (String) iter.next();
            String value = (String) valueMap.get(key);
            Predicate predicate = PredicateFactory.createPredicate(key, value); 
            map.put(key, predicate);
            
            if (predicate != null && !(predicate instanceof IdEqualsPredicate)) {
                numOfNonEqualsPredicates++;
            }
        }
        id = highestId++;
    }
    
    public boolean containsKey(Object key) {
        return map.containsKey(key);
    }
    
    public boolean containsValue(Object value) {
        return map.containsValue(value);
    }
    
    public Predicate getPredicate(String field) {
        return (Predicate) map.get(field);
    }
    
    public Set keySet() {
        return map.keySet();
    }
    
    public Set getPredicates() {
        Set result = new HashSet();
        for (Iterator iter = map.values().iterator(); iter.hasNext();) {
            Predicate pred = (Predicate) iter.next();
            if (pred != null) {
                result.add(pred);
            }
        }
        return result;
    }
    
    /**
     * @return
     */
    public int getId() {
        return id;
    }
    
    public int getNumOfNonEqualsPredicates() {
        return numOfNonEqualsPredicates;
    }
    
    public String toString() {
        return "Subscription id " + id + ": " + map;
    }
    
    public boolean equals(Object other) {
        if (other == null || !(other instanceof Subscription)) return false;
        return id == ((Subscription)other).id;
    }

    /* (non-Javadoc)
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(Object arg0) {
        Subscription other = (Subscription) arg0;
        return new Integer(id).compareTo(new Integer(other.id));
    }
}